==> qtbase-opensource-src_5.2.1+dfsg.orig.tar.xz: qtbase-opensource-src-5.2.1/src/plugins/platforms/qnx/qqnxvirtualkeyboardbps.h <==
/***************************************************************************
**
** Copyright (C) 2012 Research In Motion
** Contact: http://www.qt-project.org/legal
**
** This file is part of the plugins of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://qt.digia.com/licensing.  For further information
** use the contact form at http://qt.digia.com/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3.0 as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU General Public License version 3.0 requirements will be
** met: http://www.gnu.org/copyleft/gpl.html.
**
**
** $QT_END_LICENSE$
**
****************************************************************************/

#ifndef QQNXVIRTUALKEYBOARDBPS_H
#define QQNXVIRTUALKEYBOARDBPS_H

#include "qqnxabstractvirtualkeyboard.h"

struct bps_event_t;

QT_BEGIN_NAMESPACE

class QQnxVirtualKeyboardBps : public QQnxAbstractVirtualKeyboard
{
    Q_OBJECT
public:
    explicit QQnxVirtualKeyboardBps(QObject *parent = 0);

    bool handleEvent(bps_event_t *event);

    bool showKeyboard();
    bool hideKeyboard();

protected:
    void applyKeyboardMode(KeyboardMode mode);

private:
    bool handleLocaleEvent(bps_event_t *event);
    bool handleVirtualKeyboardEvent(bps_event_t *event);
};

QT_END_NAMESPACE

#endif // QQNXVIRTUALKEYBOARDBPS_H

==> qtbase-opensource-src_5.3.2+dfsg.orig.tar.xz: qtbase-opensource-src-5.3.2/src/plugins/platforms/qnx/qqnxvirtualkeyboardbps.h <==
/***************************************************************************
**
** Copyright (C) 2012 Research In Motion
** Contact: http://www.qt-project.org/legal
**
** This file is part of the plugins of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://qt.digia.com/licensing.  For further information
** use the contact form at http://qt.digia.com/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3.0 as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU General Public License version 3.0 requirements will be
** met: http://www.gnu.org/copyleft/gpl.html.
**
**
** $QT_END_LICENSE$
**
****************************************************************************/

#ifndef QQNXVIRTUALKEYBOARDBPS_H
#define QQNXVIRTUALKEYBOARDBPS_H

#include "qqnxabstractvirtualkeyboard.h"
#include <bps/virtualkeyboard.h>

struct bps_event_t;

QT_BEGIN_NAMESPACE

class QQnxVirtualKeyboardBps : public QQnxAbstractVirtualKeyboard
{
    Q_OBJECT
public:
    explicit QQnxVirtualKeyboardBps(QObject *parent = 0);

    bool handleEvent(bps_event_t *event);

    bool showKeyboard();
    bool hideKeyboard();

protected:
    void applyKeyboardOptions();

private:
    bool handleLocaleEvent(bps_event_t *event);
    bool handleVirtualKeyboardEvent(bps_event_t *event);

    virtualkeyboard_layout_t keyboardLayout() const;
    virtualkeyboard_enter_t enterKey() const;
};

QT_END_NAMESPACE

#endif // QQNXVIRTUALKEYBOARDBPS_H
